@@ -1,4 +1,4 @@
-/* Copyright (c) 2005-2021 Jay Berkenbilt
+/* Copyright (c) 2005-2022 Jay Berkenbilt
  *
  * This file is part of qpdf.
  *
@@ -32,27 +32,60 @@
 enum qpdf_error_code_e
 {
     qpdf_e_success = 0,
-    qpdf_e_internal,	 	/* logic/programming error -- indicates bug */
-    qpdf_e_system,		/* I/O error, memory error, etc. */
-    qpdf_e_unsupported,		/* PDF feature not (yet) supported by qpdf */
-    qpdf_e_password,		/* incorrect password for encrypted file */
-    qpdf_e_damaged_pdf,		/* syntax errors or other damage in PDF */
+    qpdf_e_internal,            /* logic/programming error -- indicates bug */
+    qpdf_e_system,              /* I/O error, memory error, etc. */
+    qpdf_e_unsupported,         /* PDF feature not (yet) supported by qpdf */
+    qpdf_e_password,            /* incorrect password for encrypted file */
+    qpdf_e_damaged_pdf,         /* syntax errors or other damage in PDF */
     qpdf_e_pages,               /* erroneous or unsupported pages structure */
+    qpdf_e_object,              /* type/bounds errors accessing objects */
+};
+
+/* Object Types */
+
+/* PDF objects represented by QPDFObjectHandle or, in the C API, by
+ * qpdf_oh, have a unique type code that has one of the values in the
+ * list below. As new object types are added to qpdf, additional items
+ * may be added to the list, so code that switches on these values
+ * should take that into consideration. (Maintainer note: it would be
+ * better to call this qpdf_ot_* rather than ot_* to reduce likelihood
+ * of name collision, but since QPDFObject::object_type_e is an alias
+ * to this type, changing the names of the values breaks backward
+ * compatibility.)
+ */
+enum qpdf_object_type_e {
+    /* Object types internal to qpdf */
+    ot_uninitialized,
+    ot_reserved,
+    /* Object types that can occur in the main document */
+    ot_null,
+    ot_boolean,
+    ot_integer,
+    ot_real,
+    ot_string,
+    ot_name,
+    ot_array,
+    ot_dictionary,
+    ot_stream,
+    /* Additional object types that can occur in content streams */
+    ot_operator,
+    ot_inlineimage,
+    /* NOTE: if adding to this list, update QPDFObject.hh */
 };
 
 /* Write Parameters. See QPDFWriter.hh for details. */
 
 enum qpdf_object_stream_e
 {
-    qpdf_o_disable = 0,		/* disable object streams */
-    qpdf_o_preserve,		/* preserve object streams */
-    qpdf_o_generate		/* generate object streams */
+    qpdf_o_disable = 0,         /* disable object streams */
+    qpdf_o_preserve,            /* preserve object streams */
+    qpdf_o_generate             /* generate object streams */
 };
 enum qpdf_stream_data_e
 {
-    qpdf_s_uncompress = 0,	/* uncompress stream data */
-    qpdf_s_preserve,		/* preserve stream data compression */
-    qpdf_s_compress		/* compress stream data */
+    qpdf_s_uncompress = 0,      /* uncompress stream data */
+    qpdf_s_preserve,            /* preserve stream data compression */
+    qpdf_s_compress             /* compress stream data */
 };
 
 /* Stream data flags */
@@ -76,22 +109,22 @@ enum qpdf_stream_decode_level_e
 
 enum qpdf_r3_print_e
 {
-    qpdf_r3p_full = 0,		/* allow all printing */
-    qpdf_r3p_low,		/* allow only low-resolution printing */
-    qpdf_r3p_none		/* allow no printing */
+    qpdf_r3p_full = 0,          /* allow all printing */
+    qpdf_r3p_low,               /* allow only low-resolution printing */
+    qpdf_r3p_none               /* allow no printing */
 };
 
 /* qpdf_r3_modify_e doesn't allow the full flexibility of the spec. It
  * corresponds to options in Acrobat 5's menus. The new interface in
  * QPDFWriter offers more granularity and no longer uses this type.
  */
-enum qpdf_r3_modify_e		/* Allowed changes: */
+enum qpdf_r3_modify_e           /* Allowed changes: */
 {
-    qpdf_r3m_all = 0,		/* All editing */
+    qpdf_r3m_all = 0,           /* All editing */
     qpdf_r3m_annotate,          /* Comments, fill forms, signing, assembly */
-    qpdf_r3m_form,		/* Fill forms, signing, assembly */
-    qpdf_r3m_assembly,		/* Only document assembly */
-    qpdf_r3m_none		/* No modifications */
+    qpdf_r3m_form,              /* Fill forms, signing, assembly */
+    qpdf_r3m_assembly,          /* Only document assembly */
+    qpdf_r3m_none               /* No modifications */
 };
 
 /* Form field flags from the PDF spec */
@@ -143,4 +176,11 @@ enum pdf_annotation_flag_e
     an_locked_contents = 1 << 9
 };
 
+/* Encryption/password status for QPDFJob */
+enum qpdf_encryption_status_e
+{
+    qpdf_es_encrypted = 1 << 0,
+    qpdf_es_password_incorrect = 1 << 1
+};
+
 #endif /* QPDFCONSTANTS_H */
